Convert Object into a Grob
# S3 method for trellis
as_grob(x, ..., device = NULL)A grob object.
An object to be converted into a grob.
Arguments passed on to grid::grid.grabExpr
warnAn integer specifying the amount of warnings to emit. 0 means no warnings, 1 means warn when it is certain that the grab will not faithfully represent the original scene. 2 means warn if there's any possibility that the grab will not faithfully represent the original scene.
wrapA logical indicating how the output should
be captured. If TRUE, each non-grob element on the
display list is captured by wrapping it in a grob.
wrap.grobsA logical indicating whether, if we are wrapping
elements (wrap=TRUE), we should wrap grobs (or just
wrap viewports).
width,heightSize of the device used for temporary rendering.
A function that opens a graphics device for temporary
rendering. By default this is an off-screen, in-memory device
based on the pdf device, but this default device may not be
satisfactory when using custom fonts.
as_grob.grob()
as_grob.gList()
as_grob.patch_ggplot()
as_grob.ggplot()
as_grob.ggalign::alignpatches()
as_grob.patchwork()
as_grob.patch()
as_grob.formula()
as_grob.recordedplot()
as_grob.trellis()
as_grob.Heatmap()
as_grob.pheatmap()
Other as_grob:
as_grob.Heatmap(),
as_grob.formula(),
as_grob.gList(),
as_grob.ggalign::alignpatches(),
as_grob.ggplot(),
as_grob.grob(),
as_grob.patch(),
as_grob.patch_ggplot(),
as_grob.patchwork(),
as_grob.pheatmap(),
as_grob.recordedplot()