By default, it calls as.matrix() to build a matrix.
# S3 method for MAF
fortify_matrix(
data,
...,
genes = NULL,
n_top = NULL,
remove_empty_samples = TRUE,
collapse_vars = FALSE
)A matrix.
An object to be converted to a matrix.
Not used currently.
An atomic character defines the genes to draw.
A single number indicates how many top genes to be drawn.
A single boolean value indicating whether to drop samples without any genomic alterations.
A single boolean value indicating whether to collapse
multiple alterations in the same sample and gene into a single value
"Multi_Hit".
gene_anno: gene summary informations
sample_anno: sample summary informations
n_genes: Total of genes
n_samples: Total of samples
breaks: factor levels of Variant_Classification, if collapse_vars = TRUE, "Multi_Hit" will be added in the end.
Other fortify_matrix methods:
fortify_matrix.default()